@@ -76,7 +76,7 @@ class Box:
     @staticmethod
     def init_format_based(
         box_format: str,
-        box_list: List[int],  # TODO should this be: Tuple[int, int, int, int] ?
+        box_list: Tuple[int, int, int, int],
         src_shape: Optional[Tuple[int, int]] = None,
         dst_shape: Optional[Tuple[int, int]] = None,
     ) -> Box:
@@ -93,12 +93,7 @@ class Box:
             A Box object
 
         """
-
-        assert len(box_list) == 4
-        assert box_list is not None
-
         if box_format == ObjectDetectionBBoxFormats.XYWH:
-
             base_box = Box(
                 xmin=int(box_list[0]),
                 ymin=int(box_list[1]),
@@ -106,22 +101,18 @@ class Box:
                 ymax=int(box_list[1] + box_list[3]),
             )
         elif box_format == ObjectDetectionBBoxFormats.XYXY:
-
             base_box = Box(
                 xmin=int(box_list[0]),
                 ymin=int(box_list[1]),
                 xmax=int(box_list[2]),
                 ymax=int(box_list[3]),
             )
-
         else:
             valid_formats = ObjectDetectionBBoxFormats.get_values_as_list(
                 class_type=ObjectDetectionBBoxFormats
             )
-
             raise ValueError(
-                f"Format {box_format} is not supported. "
-                f"Please provide any of {valid_formats}"
+                f"Format {box_format} is not supported. " f"Please provide any of {valid_formats}"
             )
 
         if src_shape is not None:
@@ -167,8 +158,11 @@ class Box:
             None
 
         """
+        if src_shape[0] < 0 or src_shape[1] < 0 or src_shape[0] > src_shape[1]:
+            raise ValueError("Invalid source shape %s: ", src_shape)
 
-        # TODO: check for correct shape values?
+        if dst_shape[0] < 0 or dst_shape[1] < 0 or dst_shape[0] > dst_shape[1]:
+            raise ValueError("Invalid destination shape %s: ", dst_shape)
 
         height_scale_factor = dst_shape[0] / src_shape[0]
         width_scale_factor = dst_shape[1] / src_shape[1]
