@@ -50,9 +50,7 @@ def replace_index_by_dir(annotation: BaseAnnotation) -> BaseAnnotation:
             how=ImplicitReplacement.FIRST,
         )
 
-        annotation = ensure_abspath(annotation=annotation)
-
-        return annotation
+        return ensure_abspath(annotation=annotation)
 
 
 def replace_dir_by_index(annotation: BaseAnnotation) -> BaseAnnotation:
@@ -82,18 +80,7 @@ def replace_dir_by_index(annotation: BaseAnnotation) -> BaseAnnotation:
             how=ImplicitReplacement.FIRST,
         )
 
-        # TODO: add this as debug logging output
-        logger.debug(
-            "Check annotation: \n"
-            " - annotation.image_path: %s \n"
-            " - annotation.image_dir: %s \n"
-            " - annotation.replacement_string: %s \n",
-            annotation.image_path,
-            annotation.image_dir,
-            annotation.replacement_string,
-        )
-
-        return annotation
+    return annotation
 
 
 def ensure_abspath(annotation: BaseAnnotation) -> BaseAnnotation:
@@ -145,20 +132,16 @@ def annotation_to_xml(
 
     for bounding_box in annotation.get_bounding_boxes(include_segmentations=True):
 
-        if (
-            allowed_classes is not None
-            and bounding_box.class_name not in allowed_classes
-        ):
+        if allowed_classes is not None and bounding_box.class_name not in allowed_classes:
             continue
 
-        # TODO: ignore error boxes?
         root = create_bbox_xml_entry(
             root,
             bounding_box.class_name,
-            bounding_box.box.xmin if bounding_box.box.xmin > 0 else 0,
-            bounding_box.box.ymin if bounding_box.box.ymin > 0 else 0,
-            bounding_box.box.xmax if bounding_box.box.xmax > 0 else 0,
-            bounding_box.box.ymax if bounding_box.box.ymax > 0 else 0,
+            bounding_box.box.xmin,
+            bounding_box.box.ymin,
+            bounding_box.box.xmax,
+            bounding_box.box.ymax,
         )
 
     logger.info("Write xml file: %s", annotation.annotation_path)
@@ -170,9 +153,7 @@ def annotation_to_xml(
         indent="  ",
     )
 
-    with open(
-        file=annotation.annotation_path, mode="w", encoding="utf8"
-    ) as annotation_file:
+    with open(file=annotation.annotation_path, mode="w", encoding="utf8") as annotation_file:
         annotation_file.write(pretty_tree_string)
 
 
@@ -272,9 +253,7 @@ def filter_annotation(
 
     for bounding_box in annotation.bounding_boxes:
         if (
-            class_ids is not None
-            and len(class_ids) > 0
-            and bounding_box.class_id not in class_ids
+            class_ids is not None and len(class_ids) > 0 and bounding_box.class_id not in class_ids
         ) or (
             class_names is not None
             and len(class_names) > 0
@@ -287,9 +266,7 @@ def filter_annotation(
 
     for segmentation in annotation.segmentations:
         if (
-            class_ids is not None
-            and len(class_ids) > 0
-            and segmentation.class_id not in class_ids
+            class_ids is not None and len(class_ids) > 0 and segmentation.class_id not in class_ids
         ) or (
             class_names is not None
             and len(class_names) > 0
